# gpt-humanizer
a Python package that enhances ChatGPT's ability to produce human-like responses while avoiding detection from AI detectors

## Installation:
```pip install gpt-humanizer```

## Usage:

```py
from GPTHumanizer import Humanizer

text = Humanizer.humanize(# input text)

print(text)
```